/********************************************************************************
** Form generated from reading UI file 'kmahjonggbackgroundselector.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KMAHJONGGBACKGROUNDSELECTOR_H
#define UI_KMAHJONGGBACKGROUNDSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KMahjonggBackgroundSelector
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QListWidget *backgroundList;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QLabel *backgroundPreview;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *labelAuthor;
    QLabel *backgroundAuthor;
    QLabel *labelContact;
    QLabel *backgroundContact;
    QLabel *labelDescription;
    QLabel *backgroundDescription;
    QLabel *label;
    QLabel *backgroundVersion;
    QLabel *label1;
    QLabel *backgroundWebsite;
    QLabel *label2;
    QLabel *backgroundCopyright;
    QLabel *label3;
    QLabel *backgroundLicense;
    QLineEdit *kcfg_Background;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KMahjonggBackgroundSelector)
    {
        if (KMahjonggBackgroundSelector->objectName().isEmpty())
            KMahjonggBackgroundSelector->setObjectName("KMahjonggBackgroundSelector");
        KMahjonggBackgroundSelector->resize(497, 446);
        KMahjonggBackgroundSelector->setMaximumSize(QSize(800, 600));
        vboxLayout = new QVBoxLayout(KMahjonggBackgroundSelector);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        backgroundList = new QListWidget(KMahjonggBackgroundSelector);
        backgroundList->setObjectName("backgroundList");
        backgroundList->setMinimumSize(QSize(120, 0));

        hboxLayout->addWidget(backgroundList);

        groupBox_2 = new QGroupBox(KMahjonggBackgroundSelector);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout1 = new QVBoxLayout(groupBox_2);
        vboxLayout1->setObjectName("vboxLayout1");
        backgroundPreview = new QLabel(groupBox_2);
        backgroundPreview->setObjectName("backgroundPreview");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(backgroundPreview->sizePolicy().hasHeightForWidth());
        backgroundPreview->setSizePolicy(sizePolicy);
        backgroundPreview->setMinimumSize(QSize(160, 120));

        vboxLayout1->addWidget(backgroundPreview);


        hboxLayout->addWidget(groupBox_2);


        vboxLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(KMahjonggBackgroundSelector);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        labelAuthor = new QLabel(groupBox);
        labelAuthor->setObjectName("labelAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelAuthor);

        backgroundAuthor = new QLabel(groupBox);
        backgroundAuthor->setObjectName("backgroundAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, backgroundAuthor);

        labelContact = new QLabel(groupBox);
        labelContact->setObjectName("labelContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelContact);

        backgroundContact = new QLabel(groupBox);
        backgroundContact->setObjectName("backgroundContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, backgroundContact);

        labelDescription = new QLabel(groupBox);
        labelDescription->setObjectName("labelDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelDescription);

        backgroundDescription = new QLabel(groupBox);
        backgroundDescription->setObjectName("backgroundDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, backgroundDescription);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        backgroundVersion = new QLabel(groupBox);
        backgroundVersion->setObjectName("backgroundVersion");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, backgroundVersion);

        label1 = new QLabel(groupBox);
        label1->setObjectName("label1");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label1);

        backgroundWebsite = new QLabel(groupBox);
        backgroundWebsite->setObjectName("backgroundWebsite");
        backgroundWebsite->setOpenExternalLinks(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, backgroundWebsite);

        label2 = new QLabel(groupBox);
        label2->setObjectName("label2");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label2);

        backgroundCopyright = new QLabel(groupBox);
        backgroundCopyright->setObjectName("backgroundCopyright");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, backgroundCopyright);

        label3 = new QLabel(groupBox);
        label3->setObjectName("label3");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label3);

        backgroundLicense = new QLabel(groupBox);
        backgroundLicense->setObjectName("backgroundLicense");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, backgroundLicense);


        vboxLayout->addWidget(groupBox);

        kcfg_Background = new QLineEdit(KMahjonggBackgroundSelector);
        kcfg_Background->setObjectName("kcfg_Background");
        kcfg_Background->setEnabled(false);
        kcfg_Background->setFrame(false);
        kcfg_Background->setReadOnly(false);

        vboxLayout->addWidget(kcfg_Background);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(KMahjonggBackgroundSelector);

        QMetaObject::connectSlotsByName(KMahjonggBackgroundSelector);
    } // setupUi

    void retranslateUi(QWidget *KMahjonggBackgroundSelector)
    {
        groupBox_2->setTitle(tr2i18n("Preview", nullptr));
        groupBox->setTitle(tr2i18n("Properties", nullptr));
        labelAuthor->setText(tr2i18n("Author:", nullptr));
        labelContact->setText(tr2i18n("Contact:", nullptr));
        labelDescription->setText(tr2i18n("Description:", nullptr));
        label->setText(tr2i18n("Version:", nullptr));
        label1->setText(tr2i18n("Website:", nullptr));
        label2->setText(tr2i18n("Copyright:", nullptr));
        label3->setText(tr2i18n("License:", nullptr));
        (void)KMahjonggBackgroundSelector;
    } // retranslateUi

};

namespace Ui {
    class KMahjonggBackgroundSelector: public Ui_KMahjonggBackgroundSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KMAHJONGGBACKGROUNDSELECTOR_H

